<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */

if ( ! function_exists( 'mega_tour_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Mega Tour 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'mega_tour_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_tour_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Mega Tour 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'mega_tour_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'mega_tour_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Mega Tour 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function mega_tour_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

/**
 * Front Page Active Callbacks
 */


/**
 * Check if Too bar section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[topbar_section_enable]' )->value() );
}
/**
 * Check if slider section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[slider_section_enable]' )->value() );
}


/**
 * Check if featured section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_featured_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[featured_section_enable]' )->value() );
}

/**
 * Check if featured section content type is page.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_featured_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_theme_options[featured_content_type]' )->value();
	return mega_tour_is_featured_section_enable( $control ) && ( 'category' == $content_type );
}


/**
 * Check if featured section content type is activity.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_featured_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_theme_options[featured_content_type]' )->value();
	return mega_tour_is_featured_section_enable( $control ) && ( 'trip-types' == $content_type );
}



/**
 * Check if about section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[about_section_enable]' )->value() );
}



/**
 * Check if package section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_package_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[package_section_enable]' )->value() );
}
/**
 * Check if about section content type is post.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_package_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_theme_options[package_content_type]' )->value();
	return mega_tour_is_package_section_enable( $control ) && ( 'page' == $content_type );
}

function mega_tour_is_package_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_theme_options[package_content_type]' )->value();
	return mega_tour_is_package_section_enable( $control ) && ( 'trip' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is category.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_theme_options[blog_content_type]' )->value();
	return mega_tour_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'mega_tour_theme_options[blog_content_type]' )->value();
	return mega_tour_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}


/**
 * Check if call to action section is enabled.
 *
 * @since Mega Tour 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function mega_tour_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'mega_tour_theme_options[cta_section_enable]' )->value() );
}


