<?php
/**
 * Package Section options
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */

// Add Package section
$wp_customize->add_section( 'mega_tour_package_section', array(
	'title'             => esc_html__( 'Package','mega-tour' ),
	'description'       => esc_html__( 'Note : Activate WP Travel plugin to enable this section options.', 'mega-tour' ),
	'panel'             => 'mega_tour_front_page_panel',
) );

// Package content enable control and setting
$wp_customize->add_setting( 'mega_tour_theme_options[package_section_enable]', array(
	'default'			=> 	$options['package_section_enable'],
	'sanitize_callback' => 'mega_tour_sanitize_switch_control',
) );

$wp_customize->add_control( new Mega_Tour_Switch_Control( $wp_customize, 'mega_tour_theme_options[package_section_enable]', array(
	'label'             => esc_html__( 'Package Section Enable', 'mega-tour' ),
	'section'           => 'mega_tour_package_section',
	'on_off_label' 		=> mega_tour_switch_options(),
) ) );

$wp_customize->add_setting( 'mega_tour_theme_options[package_count]', array(
	'default'          	=> $options['package_count'],
	'sanitize_callback' => 'mega_tour_sanitize_number_range',
	'validate_callback' => 'mega_tour_validate_package_count',
) );

$wp_customize->add_control( 'mega_tour_theme_options[package_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'mega-tour' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'mega-tour' ),
	'section'           => 'mega_tour_package_section',
	'active_callback'   => 'mega_tour_is_package_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 4,
		'style' => 'width: 100px;'
		),
) );

// Package content type control and setting
$wp_customize->add_setting( 'mega_tour_theme_options[package_content_type]', array(
	'default'          	=> $options['package_content_type'],
	'sanitize_callback' => 'mega_tour_sanitize_select',
) );

$wp_customize->add_control( 'mega_tour_theme_options[package_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mega-tour' ),
	'section'           => 'mega_tour_package_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mega_tour_is_package_section_enable',
	'choices'			=> mega_tour_package_content_type(),
) );

for ( $i=1; $i <= $options['package_count']; $i++ ) { 
	// package pages drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_theme_options[package_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Dropdown_Chooser( $wp_customize, 'mega_tour_theme_options[package_content_page_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Page %d', 'mega-tour' ), $i ),
		'section'           => 'mega_tour_package_section',
		'choices'			=> mega_tour_page_choices(),
		'active_callback'	=> 'mega_tour_is_package_section_content_page_enable',
	) ) );

	// package posts drop down chooser control and setting
	$wp_customize->add_setting( 'mega_tour_theme_options[package_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'mega_tour_sanitize_page',
	) );

	$wp_customize->add_control( new Mega_Tour_Dropdown_Chooser( $wp_customize, 'mega_tour_theme_options[package_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select trip %d', 'mega-tour' ), $i ),
		'section'           => 'mega_tour_package_section',
		'choices'			=> mega_tour_trip_choices(),
		'active_callback'	=> 'mega_tour_is_package_section_content_trip_enable',
	) ) );
}


// package button title setting and control
$wp_customize->add_setting( 'mega_tour_theme_options[package_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['package_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mega_tour_theme_options[package_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'mega-tour' ),
	'section'        	=> 'mega_tour_package_section',
	'active_callback' 	=> 'mega_tour_is_package_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mega_tour_theme_options[package_btn_title]', array(
		'selector'            => '#popular-packages .read-more a.btn',
		'settings'            => 'mega_tour_theme_options[package_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mega_tour_package_btn_title_partial',
    ) );
}
