<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */
if ( ! function_exists( 'mega_tour_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Mega Tour 1.0.0
    */
    function mega_tour_add_about_section() {
    	$options = mega_tour_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'mega_tour_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        mega_tour_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Mega Tour 1.0.0
    * @param array $input about section details.
    */
    function mega_tour_get_about_section_details( $input ) {
        $options = mega_tour_get_theme_options();
        
        $content = array();

        $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
            );                    
        
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = mega_tour_trim_content( 35 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'mega_tour_filter_about_section_details', 'mega_tour_get_about_section_details' );


if ( ! function_exists( 'mega_tour_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Mega Tour 1.0.0
   *
   */
   function mega_tour_render_about_section( $content_details = array() ) {
        $options = mega_tour_get_theme_options();

        $content = $content_details[0];
        if ( empty( $content_details ) ) {
            return;
        } 
        ?>

        <div id="about-us" class="relative page-section">
            <div class="wrapper">
                <article class="has-post-thumbnail">
                    <div class="featured-image" style="background-image: url(<?php echo esc_url($content['image']);?>)">
                    </div><!-- .featured-image -->

                    <div class="entry-container">
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                        </div><!-- .entry-content -->
                        <?php if ( !empty( $options['about_btn_title'] ) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['about_btn_title']); ?></a>
                            </div><!-- .read-more -->
                        <?php endif ?>                       
                    </div><!-- .entry-container -->
                </article>
            </div><!-- .wrapper -->
            </div><!-- #about-us -->

        <?php 
    }
endif;