<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */
if ( ! function_exists( 'mega_tour_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Mega Tour 1.0.0
    */
    function mega_tour_add_blog_section() {
    	$options = mega_tour_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'mega_tour_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'mega_tour_filter_blog_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        mega_tour_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'mega_tour_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Mega Tour 1.0.0
    * @param array $input blog section details.
    */
    function mega_tour_get_blog_section_details( $input ) {
        $options = mega_tour_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        
        $content = array();
        $args = array();
        switch ( $blog_content_type ) {

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 3,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => 3,
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );            
            break;

            default:
            break;
        }

        $content['details'] = array();
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg'; 

                // Push to the main array.
                array_push( $content['details'], $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'mega_tour_filter_blog_section_details', 'mega_tour_get_blog_section_details' );


if ( ! function_exists( 'mega_tour_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Mega Tour 1.0.0
   *
   */
   function mega_tour_render_blog_section( $content_details = array() ) {
        $options = mega_tour_get_theme_options();
        
        $blog_title = ! empty( $options['blog_title'] ) ? $options['blog_title'] : esc_html__( 'Read Our Travel Blog', 'mega-tour' );
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-posts" class="relative page-section">
            <div class="wrapper">
                <div class="section-header-wrapper clear">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($blog_title); ?></h2>
                    </div><!-- .section-header -->                   
                </div><!-- .section-header-wrapper -->

                <div class="archive-blog-wrapper clear col-3">
                    <?php foreach($content_details['details'] as $content): ?>
                    <article class="has-post-thumbnail">
                        <div class="post-item-wrapper">
                            <div class="featured-image">
                                <a href="<?php echo esc_url($content['url']); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php mega_tour_posted_on($content['id']); ?>
                                    <span class="cat-links">
                                        <?php the_category( ' ', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </div><!-- .post-item-wrapper -->
                    </article>
                    <?php endforeach; ?>
                </div><!-- .archive-blog-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->
    <?php }
endif;