<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Mega Tour
 * @since Mega Tour 1.0.0
 */

$options = mega_tour_get_theme_options();


if ( ! function_exists( 'mega_tour_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Mega Tour 1.0.0
	 */
	function mega_tour_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'mega_tour_doctype', 'mega_tour_doctype', 10 );


if ( ! function_exists( 'mega_tour_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'mega_tour_before_wp_head', 'mega_tour_head', 10 );

if ( ! function_exists( 'mega_tour_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'mega-tour' ); ?></a>

		<?php
	}
endif;
add_action( 'mega_tour_page_start_action', 'mega_tour_page_start', 10 );

if ( ! function_exists( 'mega_tour_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_header_start() {
		?>
		<div class="menu-overlay"></div>
		<header id="masthead" class="site-header" role="banner">
		<?php
	}
endif;
add_action( 'mega_tour_header_action', 'mega_tour_header_start', 10 );

if ( ! function_exists( 'mega_tour_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'mega_tour_page_end_action', 'mega_tour_page_end', 10 );



if ( ! function_exists( 'mega_tour_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_site_branding() {
		$options  = mega_tour_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="wrapper main-menu">
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo() ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( mega_tour_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name','display' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name','display' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
			<?php endif; ?>
		</div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'mega_tour_header_action', 'mega_tour_site_branding', 20 );

if ( ! function_exists( 'mega_tour_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_site_navigation() {
		$options = mega_tour_get_theme_options();
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<?php
				echo mega_tour_get_svg( array( 'icon' => 'menu' ) );
				echo mega_tour_get_svg( array( 'icon' => 'close' ) );
				?>					
				<span class="menu-label"><?php esc_html_e( 'Menu', 'mega-tour' ); ?></span>
			</button>
			<?php 

			wp_nav_menu( 
				array(
					'theme_location' => 'primary',
					'container' => 'div',
					'menu_class' => 'menu nav-menu',
					'menu_id' => 'primary-menu',
					'echo' => true,
					'fallback_cb' => 'mega_tour_menu_fallback_cb',
					'items_wrap' => '<ul id="%1$s" class="%2$s">%3$s</ul>',
					)
				);
			
        	?>
		</nav><!-- #site-navigation -->
		</div><!-- .wrapper -->
		<?php
	}
endif;
add_action( 'mega_tour_header_action', 'mega_tour_site_navigation', 30 );


if ( ! function_exists( 'mega_tour_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_header_end() {
		?>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'mega_tour_header_action', 'mega_tour_header_end', 40 );

if ( ! function_exists( 'mega_tour_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'mega_tour_content_start_action', 'mega_tour_content_start', 10 );

if ( ! function_exists( 'mega_tour_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_header_image() {
		if ( mega_tour_is_frontpage() )
			return;
		$header_image = get_header_image();
		$class = '';
		if ( is_singular() ) :
			$class = ( has_post_thumbnail() || ! empty( $header_image ) ) ? '' : 'header-media-disabled';
		else :
			$class = ! empty( $header_image ) ? '' : 'header-media-disabled';
		endif;
		
		if ( is_singular() && has_post_thumbnail() ) : 
			$header_image = get_the_post_thumbnail_url( get_the_id(), 'full' );
    	endif; ?>

    	<div id="page-site-header" class="relative <?php echo esc_attr( $class ); ?>" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
			<div class="wrapper">
				<header class="page-header">
					<?php mega_tour_custom_header_banner_title(); ?>
				</header>
				<?php mega_tour_add_breadcrumb(); ?>
			</div><!-- .wrapper -->
        </div><!-- #page-site-header -->

	<?php
	}
endif;
add_action( 'mega_tour_header_image_action', 'mega_tour_header_image', 10 );

if ( ! function_exists( 'mega_tour_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Mega Tour 1.0.0
	 */
	function mega_tour_add_breadcrumb() {
		$options = mega_tour_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( mega_tour_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * mega_tour_simple_breadcrumb hook
				 *
				 * @hooked mega_tour_simple_breadcrumb -  10
				 *
				 */
				do_action( 'mega_tour_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;

if ( ! function_exists( 'mega_tour_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_content_end() {
		?>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'mega_tour_content_end_action', 'mega_tour_content_end', 10 );

if ( ! function_exists( 'mega_tour_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'mega_tour_footer', 'mega_tour_footer_start', 10 );

if ( ! function_exists( 'mega_tour_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_footer_site_info() {
		$options = mega_tour_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'.  get_bloginfo( 'name', 'display' ). '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );
        $options['powered_by_text'] = str_replace( $search, $replace, $options['powered_by_text'] );

		$copyright_text = $options['copyright_text']; 
		$powered_by_text = $options['powered_by_text'];
		?>
		<div class="site-info col-2">
                <div class="wrapper">
                    <span class="copyright">
                    	<?php 
                    	echo mega_tour_santize_allow_tag( $copyright_text ); 
                    	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                    	?>
                	</span>
                    <span class="powered-by"><?php echo mega_tour_santize_allow_tag( $powered_by_text ); ?></span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'mega_tour_footer', 'mega_tour_footer_site_info', 40 );

if ( ! function_exists( 'mega_tour_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_footer_scroll_to_top() {
		$options  = mega_tour_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo mega_tour_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'mega_tour_footer', 'mega_tour_footer_scroll_to_top', 40 );

if ( ! function_exists( 'mega_tour_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_footer_end() {
		?>
		</footer>
		<div class="popup-overlay"></div>
		<?php
	}
endif;
add_action( 'mega_tour_footer', 'mega_tour_footer_end', 100 );

if ( ! function_exists( 'mega_tour_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_loader() {
		$options = mega_tour_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo mega_tour_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'mega_tour_before_header', 'mega_tour_loader', 10 );

if ( ! function_exists( 'mega_tour_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Mega Tour 1.0.0
	 *
	 */
	function mega_tour_infinite_loader_spinner() { 
		global $post;
		$options = mega_tour_get_theme_options();
		if ( ($options['pagination_type'] == 'infinite') ):
			if ( count((array) $post ) > 0 ) {
				echo '<div class="blog-loader">' . mega_tour_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'mega_tour_infinite_loader_spinner_action', 'mega_tour_infinite_loader_spinner', 10 );
